LootLog = {
	name = "LootLog",
	slashCommand = "/lootlog",
	verbose = false,
	mine = false,

	-- List of items to whitelist as notable
	notableIDs = {
		[56862] = true,	-- Fortified Nirncrux
		[56863] = true,	-- Potent Nirncrux
		[68342] = true,	-- Hakeijo
	}
};

function LootLog.OnAddOnLoaded( eventCode, addonName )
	if (addonName ~= LootLog.name) then return end

	EVENT_MANAGER:UnregisterForEvent(LootLog.name, EVENT_ADD_ON_LOADED);
	EVENT_MANAGER:RegisterForEvent(LootLog.name, EVENT_LOOT_RECEIVED, LootLog.OnLootReceived);
	SLASH_COMMANDS[LootLog.slashCommand] = LootLog.HandleSlashCommand;
end

function LootLog.OnLootReceived( eventCode, receivedBy, itemName, quantity, itemSound, lootType, self, isPickpocketLoot, questItemIcon, itemId )
	-- Notable items are: any set items, any purple+ items, blue+ special items (e.g., treasure maps)

	if (lootType ~= LOOT_TYPE_ITEM and lootType ~= LOOT_TYPE_COLLECTIBLE) then return end

	local itemType, specializedItemType = GetItemLinkItemType(itemName);
	local itemQuality = GetItemLinkQuality(itemName);
	local itemIsSet = GetItemLinkSetInfo(itemName);

	-- Workaround for a ZOS bug: Daedric Embers are not flagged in-game as key fragments
	if (itemId == 69059) then specializedItemType = SPECIALIZED_ITEMTYPE_TROPHY_KEY_FRAGMENT end

	local itemIsKeyFragment = (itemType == ITEMTYPE_TROPHY) and (specializedItemType == SPECIALIZED_ITEMTYPE_TROPHY_KEY_FRAGMENT);
	local itemIsSpecial = (itemType == ITEMTYPE_TROPHY and not itemIsKeyFragment) or (itemType == ITEMTYPE_COLLECTIBLE) or IsItemLinkConsumable(itemName);

	if ( (LootLog.verbose) or
	     (itemIsSet) or
	     (itemQuality >= ITEM_QUALITY_ARCANE and itemIsSpecial) or
	     (itemQuality >= ITEM_QUALITY_ARTIFACT and not itemIsKeyFragment) or
	     (lootType == LOOT_TYPE_COLLECTIBLE) or
	     (LootLog.notableIDs[itemId]) ) then
		LootLog.LogItem(itemName, itemType, quantity, self and "" or receivedBy);
	end
end

function LootLog.LogItem( itemName, itemType, quantity, receivedBy )
	local formattedRecipient;
	local formattedQuantity = "";
	local formattedTrait = "";

	if (receivedBy == "") then
		formattedRecipient = GetString(SI_LOOTLOG_SELF_IDENTIFIER);
	else
		-- Create a character link to make it easier to contact the recipient
		formattedRecipient = string.format("|H0:character:%s|h%s|h", receivedBy, receivedBy:gsub("%^%a+$", "", 1));
	end

	if (quantity > 1) then
		formattedQuantity = string.format("|cFFFFFFx%d|r", quantity);
	end

	local traitType = GetItemLinkTraitInfo(itemName);

	if (traitType ~= ITEM_TRAIT_TYPE_NONE and itemType ~= ITEMTYPE_ARMOR_TRAIT and itemType ~= ITEMTYPE_WEAPON_TRAIT) then
		formattedTrait = string.format(" |cFFFFFF(%s)|r", GetString("SI_ITEMTRAITTYPE", traitType));
	end

	if ((LootLog.mine == true) and (receivedBy ~= "")) then return end

	LootLog.Msg(string.format(
		"%s%s%s → |c%06X%s|r",
		itemName:gsub("^|H0", "|H1", 1),
		formattedQuantity,
		formattedTrait,
		HashString(formattedRecipient) % 0x1000000,	-- Use the hash of the name for the color so that is random, but consistent
		formattedRecipient
	));

end

function LootLog.Msg( text )
	local msg = "[Loot Log] " .. text;

	if (CHAT_SYSTEM.primaryContainer) then
		-- If possible, post as a System message so that it can appear in multiple tabs.
		CHAT_SYSTEM.primaryContainer:OnChatEvent(nil, msg, CHAT_CATEGORY_SYSTEM);
	else
		CHAT_SYSTEM:AddMessage(msg);
	end
end

function LootLog.HandleSlashCommand( command )
	if (command == "verbose") then
		LootLog.verbose = not LootLog.verbose;
		LootLog.Msg(GetString("SI_LOOTLOG_VERBOSE_STATUS", LootLog.verbose and 1 or 0));
	else
		LootLog.Msg(GetString(SI_LOOTLOG_INVALID_SLASH_COMMAND));
	end

	if (command == "mine") then
		LootLog.mine = not LootLog.mine;
		LootLog.Msg(GetString("SI_LOOTLOG_MINE_STATUS", LootLog.mine and 1 or 0));
	else
		LootLog.Msg(GetString(SI_LOOTLOG_INVALID_MINE_SLASH_COMMAND));
	end
end

EVENT_MANAGER:RegisterForEvent(LootLog.name, EVENT_ADD_ON_LOADED, LootLog.OnAddOnLoaded);
